==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/MistakeSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MistakeSpecFluent<A extends MistakeSpecFluent<A>> extends BaseFluent<A>{
  public MistakeSpecFluent() {
  }
  public MistakeSpecFluent(MistakeSpec instance) {
    instance = (instance != null ? instance : new MistakeSpec());

    if (instance != null) {
      this.withFilling(instance.getFilling());
      this.withMaxLength(instance.getMaxLength());
      this.withMaxOccurrences(instance.getMaxOccurrences());
      this.withFilling(instance.getFilling());
      this.withMaxLength(instance.getMaxLength());
      this.withMaxOccurrences(instance.getMaxOccurrences());
    }
  }
  private String filling;
  private Long maxLength;
  private Long maxOccurrences;
  public String getFilling() {
    return this.filling;
  }
  public A withFilling(String filling) {
    this.filling=filling; return (A) this;
  }
  public boolean hasFilling() {
    return this.filling != null;
  }
  public Long getMaxLength() {
    return this.maxLength;
  }
  public A withMaxLength(Long maxLength) {
    this.maxLength=maxLength; return (A) this;
  }
  public boolean hasMaxLength() {
    return this.maxLength != null;
  }
  public Long getMaxOccurrences() {
    return this.maxOccurrences;
  }
  public A withMaxOccurrences(Long maxOccurrences) {
    this.maxOccurrences=maxOccurrences; return (A) this;
  }
  public boolean hasMaxOccurrences() {
    return this.maxOccurrences != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MistakeSpecFluent that = (MistakeSpecFluent) o;
    if (!java.util.Objects.equals(filling, that.filling)) return false;

    if (!java.util.Objects.equals(maxLength, that.maxLength)) return false;

    if (!java.util.Objects.equals(maxOccurrences, that.maxOccurrences)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(filling,  maxLength,  maxOccurrences,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (filling != null) { sb.append("filling:"); sb.append(filling + ","); }
    if (maxLength != null) { sb.append("maxLength:"); sb.append(maxLength + ","); }
    if (maxOccurrences != null) { sb.append("maxOccurrences:"); sb.append(maxOccurrences); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/MistakeSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class MistakeSpecFluent<A extends MistakeSpecFluent<A>> extends BaseFluent<A>{
  public MistakeSpecFluent() {
  }
  
  public MistakeSpecFluent(MistakeSpec instance) {
    this.copyInstance(instance);
  }
  private String filling;
  private Long maxLength;
  private Long maxOccurrences;
  
  protected void copyInstance(MistakeSpec instance) {
    instance = (instance != null ? instance : new MistakeSpec());
  
    if (instance != null) {
        this.withFilling(instance.getFilling());
        this.withMaxLength(instance.getMaxLength());
        this.withMaxOccurrences(instance.getMaxOccurrences());
        this.withFilling(instance.getFilling());
        this.withMaxLength(instance.getMaxLength());
        this.withMaxOccurrences(instance.getMaxOccurrences());
      }
  }
  
  public String getFilling() {
    return this.filling;
  }
  
  public A withFilling(String filling) {
    this.filling=filling; return (A) this;
  }
  
  public boolean hasFilling() {
    return this.filling != null;
  }
  
  public Long getMaxLength() {
    return this.maxLength;
  }
  
  public A withMaxLength(Long maxLength) {
    this.maxLength=maxLength; return (A) this;
  }
  
  public boolean hasMaxLength() {
    return this.maxLength != null;
  }
  
  public Long getMaxOccurrences() {
    return this.maxOccurrences;
  }
  
  public A withMaxOccurrences(Long maxOccurrences) {
    this.maxOccurrences=maxOccurrences; return (A) this;
  }
  
  public boolean hasMaxOccurrences() {
    return this.maxOccurrences != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MistakeSpecFluent that = (MistakeSpecFluent) o;
    if (!java.util.Objects.equals(filling, that.filling)) return false;
  
    if (!java.util.Objects.equals(maxLength, that.maxLength)) return false;
  
    if (!java.util.Objects.equals(maxOccurrences, that.maxOccurrences)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(filling,  maxLength,  maxOccurrences,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (filling != null) { sb.append("filling:"); sb.append(filling + ","); }
    if (maxLength != null) { sb.append("maxLength:"); sb.append(maxLength + ","); }
    if (maxOccurrences != null) { sb.append("maxOccurrences:"); sb.append(maxOccurrences); }
    sb.append("}");
    return sb.toString();
  }
  

}
